pub struct OutputPrefixInTransactionV5 {
pub cv: ValueCommitment,
pub cm_u: ExtractedNoteCommitment,
pub ephemeral_key: EphemeralPublicKey,
pub enc_ciphertext: EncryptedNote,
pub out_ciphertext: WrappedNoteKey,
}Expand description
The serialization prefix fields of an Output in Transaction V5.
In V5 transactions, spends are split into multiple arrays, so the prefix
and proof must be serialised and deserialized separately.
Serialized as OutputDescriptionV5 in protocol specification 7.3.
Fields
cv: ValueCommitmentA value commitment to the value of the input note.
cm_u: ExtractedNoteCommitmentThe u-coordinate of the note commitment for the output note.
ephemeral_key: EphemeralPublicKeyAn encoding of an ephemeral Jubjub public key.
enc_ciphertext: EncryptedNoteA ciphertext component for the encrypted output note.
out_ciphertext: WrappedNoteKeyA ciphertext component for the encrypted output note.